## Extensions

Extend Glyphs with scripts and plug-ins.
There are many existing scripts and plug-ins that can be freely downloaded from the Plugin Manager.
Commercial extensions are also available online.
Write custom extensions to satisfy specific needs.

All scripts and most plug-ins are written in the Python programming language.
For these to run inside Glyphs, ensure that Python is set up in the settings.